Coverage for src/su6/__init__.py: 100%

1"""

2 This file exposes 'app' to the module.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8

9 from rich import print

10

11 from .cli import app

12 from .core import GREEN_CIRCLE, RED_CIRCLE, print_json, state

13

14# for plugins:

15 from .plugins import register as register_plugin

16 from .plugins import run_tool

17

18 __all__ = ["app", "print", "GREEN_CIRCLE", "RED_CIRCLE", "print_json", "state", "register_plugin", "run_tool"]